==> hinemos_src-3.2.2.tar.gz: VendorSrc/NTSyslog-1.15-R2-Hinemos/NTSyslogCtrl/resource.h <==
//{{NO_DEPENDENCIES}}
// Microsoft Visual C++ generated include file.
// Used by NTSyslogCtrl.rc
//
#define IDM_ABOUTBOX                    0x0010
#define IDC_ABOUTBOX                    0x0010
#define IDD_ABOUTBOX                    100
#define IDD_NTSYSLOGCTRL_DIALOG         101
#define IDD_SYSTEM_DIALOG               102
#define IDD_SYSLOGD_DIALOG              103
#define IDD_APPLICATION_DIALOG          104
#define IDD_SECURITY_DIALOG             105
#define IDD_SERVER_DIALOG               106
#define IDS_ABOUTBOX                    107
#define IDR_MAINFRAME                   128
#define IDI_GREEN_ICON                  129
#define IDI_YELLOW_ICON                 130
#define IDI_RED_ICON                    131
#define IDI_ERROR_ICON                  132
#define IDC_STATUS_LIGHT                200
#define IDC_STATUS                      201
#define IDC_SELECT_COMPUTER             202
#define IDC_START                       203
#define IDC_STOP                        204
#define IDC_SYSLOGD                     205
#define IDC_APPLICATIONS                206
#define IDC_SECURITY                    207
#define IDC_SYSTEM                      208
#define IDC_COMPUTER                    209
#define IDC_INFORMATION_CHECK           210
#define IDC_WARNING_CHECK               211
#define IDC_PRIMARY_SYSLOGD             212
#define IDC_ERROR_CHECK                 213
#define IDC_BACKUP_SYSLOGD              214
#define IDC_DEFAULTS                    215
#define IDC_AUDIT_SUCCESS_CHECK         216
#define IDC_AUDIT_FAILURE_CHECK         217
#define IDC_LABEL                       220
#define IDC_INFO_FACILITY               221
#define IDC_INFO_SEVERITY               222
#define IDC_WARNING_FACILITY            223
#define IDC_EVENTLOG_SELECT             223
#define IDC_WARNING_SEVERITY            224
#define IDC_EVENTLOG                    224
#define IDC_ERROR_FACILITY              225
#define IDC_ERROR_SEVERITY              226
#define IDC_AUDIT_SUCCESS_FACILITY      227
#define IDC_AUDIT_SUCCESS_SEVERITY      228
#define IDC_FULLCN_NON                  228
#define IDC_AUDIT_FAILURE_FACILITY      229
#define IDC_STRINGCODE                  229
#define IDC_CHARCODE                    229
#define IDC_                            229
#define IDC_DEBUG_MODE                  229
#define IDC_AUDIT_FAILURE_SEVERITY      230
#define IDD_CONFIG_LOG                  301
#define IDS_APPLICATION_LOG_TITLE       57345
#define IDS_APPLICATION_LOG_PATH        57346
#define IDS_SECURITY_LOG_TITLE          57347
#define IDS_SECURITY_LOG_PATH           57348
#define IDS_SYSTEM_LOG_TITLE            57349
#define IDS_SYSTEM_LOG_PATH             57350
#define IDS_CONFIRM_SAVE                57351
#define IDS_CONFIRM_DISCARD             57352

// Next default values for new objects
// 
#ifdef APSTUDIO_INVOKED
#ifndef APSTUDIO_READONLY_SYMBOLS
#define _APS_NEXT_RESOURCE_VALUE        304
#define _APS_NEXT_COMMAND_VALUE         32771
#define _APS_NEXT_CONTROL_VALUE         230
#define _APS_NEXT_SYMED_VALUE           108
#endif
#endif

==> hinemos_src-4.0.3.tar.gz: VendorSrc/NTSyslog-1.15-R2-Hinemos/NTSyslogCtrl/resource.h <==
//{{NO_DEPENDENCIES}}
// Microsoft Visual C++ generated include file.
// Used by NTSyslogCtrl.rc
//
#define IDM_ABOUTBOX                    0x0010
#define IDC_ABOUTBOX                    0x0010
#define IDD_ABOUTBOX                    100
#define IDD_NTSYSLOGCTRL_DIALOG         101
#define IDD_SYSTEM_DIALOG               102
#define IDD_SYSLOGD_DIALOG              103
#define IDD_APPLICATION_DIALOG          104
#define IDD_SECURITY_DIALOG             105
#define IDD_SERVER_DIALOG               106
#define IDS_ABOUTBOX                    107
#define IDR_MAINFRAME                   128
#define IDI_GREEN_ICON                  129
#define IDI_YELLOW_ICON                 130
#define IDI_RED_ICON                    131
#define IDI_ERROR_ICON                  132
#define IDC_STATUS_LIGHT                200
#define IDC_STATUS                      201
#define IDC_SELECT_COMPUTER             202
#define IDC_START                       203
#define IDC_STOP                        204
#define IDC_SYSLOGD                     205
#define IDC_APPLICATIONS                206
#define IDC_SECURITY                    207
#define IDC_SYSTEM                      208
#define IDC_COMPUTER                    209
#define IDC_INFORMATION_CHECK           210
#define IDC_WARNING_CHECK               211
#define IDC_PRIMARY_SYSLOGD             212
#define IDC_ERROR_CHECK                 213
#define IDC_BACKUP_SYSLOGD              214
#define IDC_DEFAULTS                    215
#define IDC_AUDIT_SUCCESS_CHECK         216
#define IDC_AUDIT_FAILURE_CHECK         217
#define IDC_CRITICAL_CHECK				218
#define IDC_LABEL                       220
#define IDC_INFO_FACILITY               221
#define IDC_INFO_SEVERITY               222
#define IDC_WARNING_FACILITY            223
#define IDC_EVENTLOG_SELECT             223
#define IDC_WARNING_SEVERITY            224
#define IDC_EVENTLOG                    224
#define IDC_ERROR_FACILITY              225
#define IDC_ERROR_SEVERITY              226
#define IDC_AUDIT_SUCCESS_FACILITY      227
#define IDC_AUDIT_SUCCESS_SEVERITY      228
#define IDC_FULLCN_NON                  228
#define IDC_AUDIT_FAILURE_FACILITY      229
#define IDC_STRINGCODE                  229
#define IDC_CHARCODE                    229
#define IDC_                            229
#define IDC_DEBUG_MODE                  229
#define IDC_AUDIT_FAILURE_SEVERITY      230
#define IDC_CRITICAL_FACILITY		    231
#define IDC_CRITICAL_SEVERITY		    232
#define IDC_LOGALWAYS_CHECK				233
#define IDC_LOGALWAYS_FACILITY			234
#define IDC_LOGALWAYS_SEVERITY			235
#define IDC_VERBOSE_CHECK				236
#define IDC_VERBOSE_FACILITY			237
#define IDC_VERBOSE_SEVERITY			238


#define IDD_CONFIG_LOG                  301

#define IDS_APPLICATION_LOG_TITLE       57345
#define IDS_APPLICATION_LOG_PATH        57346
#define IDS_SECURITY_LOG_TITLE          57347
#define IDS_SECURITY_LOG_PATH           57348
#define IDS_SYSTEM_LOG_TITLE            57349
#define IDS_SYSTEM_LOG_PATH             57350
#define IDS_CONFIRM_SAVE                57351
#define IDS_CONFIRM_DISCARD             57352

// Next default values for new objects
// 
#ifdef APSTUDIO_INVOKED
#ifndef APSTUDIO_READONLY_SYMBOLS
#define _APS_NEXT_RESOURCE_VALUE        304
#define _APS_NEXT_COMMAND_VALUE         32771
#define _APS_NEXT_CONTROL_VALUE         230
#define _APS_NEXT_SYMED_VALUE           108
#endif
#endif
